<?php

/**
 * Plugin Name: VOO Shipping for WooCommerce
 * Description: WooCommerce integration for VOO eCommerce
 * Author: VOO
 * Author URI: https://getvoo.com/
 * Version: 1.0
 * Requires at least: 5.0
 * Tested up to: 5.5
 * WC requires at least: 2.6
 * WC tested up to: 4.4.1
 * Text Domain: voo-woocommerce
 * Domain Path: /languages
 *
 */

if (!defined('ABSPATH')) {
    exit; // Exit if accessed directly
}
$citiesCode = array(
    "EG-01" => "Cairo",
    "EG-02" => "Alexandria",
    "EG-03" => "Sahel",
    "EG-04" => "Behira",
    "EG-05" => "Dakahlia",
    "EG-06" => "El Kalioubia",
    "EG-07" => "Gharbia",
    "EG-08" => "Kafr Alsheikh",
    "EG-09" => "Monufia",
    "EG-10" => "Sharqia",
    "EG-11" => "Isamilia",
    "EG-12" => "Suez",
    "EG-13" => "Port Said",
    "EG-14" => "Damietta",
    "EG-15" => "Fayoum",
    "EG-16" => "Bani Suif",
    "EG-17" => "Assuit",
    "EG-18" => "Sohag",
    "EG-19" => "Menya",
    "EG-20" => "Qena",
    "EG-21" => "Aswan",
    "EG-22" => "Luxor",
);

$specific_zones = [
    "Cairo" => [

    ],
    "Alexandria" => "Alexandria",
    "Sahel" => "North Coast",
    "Behira" => "Behira",
    "Dakahlia" => "Mansoura",
    "El Kalioubia" => "Quliob",
    "Gharbia" => [
        "Tanta", "Mahla"
    ],
    "Kafr Alsheikh" => "Kafr el Sheikh",
    "Monufia" => "Monofia",
    "Sharqia" => "El Sharkia",
    "Isamilia" => "Ismailya",
    "Suez" => "suez",
    "Port Said" => "Port said",
    "Damietta" => "Dommyat",
    "Fayoum" => "Fayoum",
    "Bani Suif" => "Benisuif",
    "Assuit" => "Asyut",
    "Sohag" => "Souhag",
    "Menya" => "Minya",
    "Qena" => "Quena",
    "Aswan" => "Aswan",
    "Luxor" => "Luxor",
];
// add notice to config plugin
add_action('admin_notices', 'voo_woocommerce_notice');
function voo_woocommerce_notice()
{
    //check if woocommerce installed and activated
    if (!class_exists('WooCommerce')) {
        echo
        '<div class="error notice-warning text-bold">
        <p>
        <img src="' . esc_url(plugins_url('assets/images/voo.svg', __FILE__)) . '" alt="VOO" style="height:13px; width:25px;">
        <strong>' . sprintf(esc_html__('VOO requires WooCommerce to be installed and active. You can download %s here.'), '<a href="https://woocommerce.com/" target="_blank">WooCommerce</a>') . '</strong>
        </p>
        </div>';
        return;
    }
}

add_action('admin_menu', 'voo_setup_menu');
function voo_setup_menu()
{
    //check if woocommerce is activated
    if (!class_exists('WooCommerce')) {
        return;
    }

    add_menu_page(
        'Test Plugin Page',
        'VOO',
        'manage_options',
        'voo-woocommerce',
        'voo_setting',
        esc_url(plugins_url('assets/images/voo.svg', __FILE__))
    );

    // link to plugin settings
    add_submenu_page(
        'voo-woocommerce',
        'Setting',
        'Setting',
        'manage_options',
        'voo-woocommerce',
        'voo_setting'
    );

    // link to woocommerce orders
    add_submenu_page(
        'voo-woocommerce',
        'Send Orders',
        'Send Orders',
        'manage_options',
        'voo-woocommerce-orders',
        'voo_orders'
    );

    // link to voo shipments
    add_submenu_page(
        'voo-woocommerce',
        'Track VOO Orders',
        'Track VOO Orders',
        'manage_options',
        'voo-woocommerce-shipments',
        'voo_dashboard'
    );
}

function voo_setting()
{
    $redirect_url = admin_url('admin.php?') . 'page=wc-settings&tab=shipping&section=voo';
    wp_redirect($redirect_url);
}

function voo_orders()
{
    $redirect_url = admin_url('edit.php?') . 'post_type=shop_order&paged=1';
    wp_redirect($redirect_url);
}

function voo_dashboard()
{
    $redirect_url = 'https://my.getvoo.com/merchants/shipments';
    wp_redirect($redirect_url);
}

add_action('load-edit.php', 'voo_wco_load', 20);
function voo_wco_load()
{
    $orders = wc_get_orders(array('return' => 'ids'));
    $keys = [];
    foreach($orders as $order) {
        $key = get_post($order)->post_password;
        $keys['keys'][] = $key;
    }
    $url = 'https://my.getvoo.com/api/getWooCommerceData/';
    $APIKey = get_option('woocommerce_voo_settings')['APIKey'];
    $result = wp_remote_get($url,
                array('timeout' => 30,
                    'method' => 'POST',
                    'headers' => array(
                        'Content-Type' => 'application/json',
                        'authorization' => $APIKey,
                        'X-Requested-By' => 'WooCommerce',
                    ),
                    'body' => json_encode($keys),
            ));
            // die($result['body']);

    foreach($orders as $index => $order) {
        $tracking_number = json_decode($result['body'])->data[$index]->code;
        $tracking_status = json_decode($result['body'])->data[$index]->status;
        $payment_link = json_decode($result['body'])->data[$index]->payment_link;
        $cash_collection = json_decode($result['body'])->data[$index]->cash_collection;
        $payment_status = json_decode($result['body'])->data[$index]->payment_status;
        
        if($tracking_status && $tracking_status != 'cancelled') {
            delete_post_meta($order, 'voo_status');
            delete_post_meta($order, 'voo_tracking_number');
            delete_post_meta($order, 'voo_payment_link');
            delete_post_meta($order, 'voo_cash_collection');
            delete_post_meta($order, 'voo_payment_status');
            add_post_meta($order, 'voo_status', $tracking_status);
            add_post_meta($order, 'voo_tracking_number', $tracking_number);
            add_post_meta($order, 'voo_cash_collection', $cash_collection);
            if($payment_link) {
                add_post_meta($order, 'voo_payment_link', $payment_link);
            }
            if($payment_status) {
                add_post_meta($order, 'voo_payment_status', $payment_status);
            }
        } else {
            delete_post_meta($order, 'voo_status');
            delete_post_meta($order, 'voo_tracking_number');
            delete_post_meta($order, 'voo_payment_link');
            delete_post_meta($order, 'voo_cash_collection');
            delete_post_meta($order, 'voo_payment_status');
        }
    }
    // $test = ;
    // die(json_encode($test));
    $screen = get_current_screen();
    if (!isset($screen->post_type) || 'shop_order' != $screen->post_type) {
        return;
    }

    add_filter("manage_{$screen->id}_columns", 'voo_wco_add_columns');
    add_action("manage_{$screen->post_type}_posts_custom_column", 'voo_wco_column_cb_data', 10, 2);
}

function voo_wco_add_columns($columns)
{
    $order_total = $columns['order_total'];
    $order_date = $columns['order_date'];
    unset($columns['order_total']);
    unset($columns['order_date']);

    $columns["voo_status"] = __("VOO Status", "themeprefix");
    $columns["voo_tracking_number"] = __("VOO Tracking Number", "themeprefix");
    $columns['order_date'] = $order_date;
    $columns["order_price"] = __("Order Price", "themeprefix");
    // $columns['order_total'] = $order_total;
    $columns['shipping_request'] = __("Ship With VOO", "themeprefix");
    $columns['payment_column'] = __("Payment Link", "themeprefix");
    $columns['order_total2'] = __("Total Price", "themeprefix");

    return $columns;
}

function voo_wco_column_cb_data($colname, $orderId)
{
    $key = get_post_meta($orderId, '_order_key', true);
    $url = 'https://my.getvoo.com/api/getWooCommerceData/' . $key;
    $voo_status = get_post_meta($orderId, 'voo_status', true);
    $trackingNumber = get_post_meta($orderId, 'voo_tracking_number', true);
    $APIKey = get_option('woocommerce_voo_settings')['APIKey'];

    $custom_status = ['To be picked', 'To be delivered', 'Delivered', 'Returned'];
    if($colname == 'order_total2') {
        $order_total = get_post_meta($orderId, 'voo_cash_collection', true);
        if (!empty($order_total)) {
            echo $order_total;
        } else {
            echo "---";
        }
    }
    if($colname == 'order_price') {
        $order_price = get_post_meta($orderId, '_order_total', true);
        if (!empty($order_price)) {
            echo $order_price;
        } else {
            echo "---";
        }
    }
    if($colname == 'shipping_request' && $voo_status == 'to_be_picked') {
        $bearerToken = get_option('woocommerce_voo_settings')['APIKey'];
        echo("<a href='#'><span class='btn btn-danger cancel-button' data-key='$key' bearerToken='$bearerToken'>Cancel</span></a>");
    }
    if($colname == "shipping_request" && (empty($voo_status) || $voo_status == 'cancelled') && !in_array($voo_status, $custom_status)) {
        $city = get_post_meta($orderId, '_shipping_state', true);
        $total = get_post_meta($orderId, '_order_total', true);
        $key = get_post_meta($orderId, '_order_key', true);
        $shipping_address = get_post_meta($orderId, '_billing_address_index', true);
        $mobile = get_post_meta($orderId, '_billing_phone', true);
        $customer_first_name = get_post_meta($orderId, '_billing_first_name', true);
        $customer_last_name = get_post_meta($orderId, '_billing_last_name', true);
        $bearerToken = get_option('woocommerce_voo_settings')['APIKey'];
        
        $args = array('post__in' => [$orderId]);
        $order = wc_get_orders($args);
        $items = $order[0]->get_items();
        $desc = 'Products: ';
        foreach ($items as $item_id => $item_data) {
            $product = $item_data->get_product();
            $product_name = $product->get_name();
            $item_quantity = $item_data->get_quantity();
            $desc .= $product_name . '(' . $item_quantity . ') ';
        }
        
        echo("<a href='#'><span class='btn btn-success shipping-button' data-key='$key' bearerToken='$bearerToken' data-city='$city' data-total='$total'>Ship</span></a>
                <input type='hidden' bearerToken='$bearerToken' id='$key' data-city='$city' data-description='$desc' data-total='$total' 
                    data-address='$shipping_address' data-mobile='$mobile' data-name='$customer_first_name $customer_last_name' data-wordpress-id='$orderId'>
                <input type='hidden' class='fedex-total-fees' value='0'>
                <input type='hidden' class='fetchr-total-fees' value='0'>
                <input type='hidden' class='aramex-total-fees' value='0'>
                <input type='hidden' class='mylerz-total-fees' value='0'>
                <inpit type='hidden' class='payment-way' value='4'");
    }

    if ($colname == 'voo_status') {
        $voo_status = get_post_meta($orderId, 'voo_status', true);
        if (!empty($voo_status)) {
            echo $voo_status;
        } else {
            echo "---";
        }
    }

    if ($colname == 'payment_column') {
        $voo_payment = get_post_meta($orderId, 'voo_payment_link', true);
        $voo_payment_status = get_post_meta($orderId, 'voo_payment_status', true);
        if (!empty($voo_payment)) {
            echo "$voo_payment <br> <span class='badge badge-warning'>$voo_payment_status</span>";
        } else {
            echo "---";
        }
    }

    if ($colname == 'voo_tracking_number') {
        $trackingNumber = get_post_meta($orderId, 'voo_tracking_number', true);
        $voo_status = get_post_meta($orderId, 'voo_status', true);
        if (!empty($trackingNumber) && $voo_status != 'Cancelled') {
            echo $trackingNumber;
        } else {
            echo "---";
        }
    }
}

/**
 * Enqueue a script in the WordPress admin on edit.php.
 *
 * @param int $hook Hook suffix for the current admin page.
 */
function voo_wpdocs_selectively_enqueue_admin_script( $hook ) {
    if ( 'edit.php' != $hook ) {
        return;
    }
    echo ("
            <style>
                .swal2-popup.swal2-modal {
                    width: fit-content;
                }
                .top2 {
                    display: flex;
                    -webkit-box-orient: vertical;
                    -webkit-box-direction: normal;
                    -ms-flex-direction: column;
                    flex-direction: column;
                    -webkit-box-align: center;
                    -ms-flex-align: center;
                    align-items: center;
                    -webkit-box-pack: center;
                    -ms-flex-pack: center;
                    justify-content: center;
                    width: 100%;
                    height: 100px;
                }
            </style>");
    wp_enqueue_style( 'bootstrap_style_sheet', plugin_dir_url( __FILE__ ) . 'css/bootstrap.min.css', array(), '1.0' );
    wp_enqueue_style( 'sweetalert2_style_sheet', plugin_dir_url( __FILE__ ) . 'css/sweetalert2.min.css', array(), '1.0' );
    wp_enqueue_script( 'popper_script', plugin_dir_url( __FILE__ ) . 'js/popper.min.js', array(), '1.0' );
    wp_enqueue_script( 'sweetalert2_script', plugin_dir_url( __FILE__ ) . 'js/sweetalert2.min.js', array(), '1.0' );
    wp_enqueue_script( 'my_custom_script', plugin_dir_url( __FILE__ ) . 'js/voo.js', array(), '1.0' );
}
add_action( 'admin_enqueue_scripts', 'voo_wpdocs_selectively_enqueue_admin_script' );


add_filter('plugin_action_links_' . plugin_basename(__FILE__), 'voo_plugin_action_links');
function voo_plugin_action_links($links)
{
    $plugin_links = array(
        '<a href="' . menu_page_url('voo-woocommerce', false) . '">' . __('Settings') . '</a>',
    );

    return array_merge($plugin_links, $links);
}

add_action('plugins_loaded', 'init_voo_shipping_class');
function init_voo_shipping_class()
{
    //check if woocommerce is activated
    if (!class_exists('WooCommerce')) {
        return;
    }

    if (!class_exists('voo_Shipping_Method')) {
        class voo_Shipping_Method extends WC_Shipping_Method
        {
            public function __construct()
            {
                $this->id = 'voo';
                $this->method_title = __('VOO Shipping', 'voo');
                $this->method_description = __('Custom Shipping Method for voo', 'voo');

                $this->init();
                $this->enabled = isset($this->settings['enabled']) ? $this->settings['enabled'] : 'yes';
                $this->title = isset($this->settings['title']) ? $this->settings['title'] : __('voo Shipping', 'voo');

            }

            function init()
            {
                $this->init_form_fields();
                $this->init_settings();
                add_action('woocommerce_update_options_shipping_' . $this->id, array($this, 'process_admin_options'));
            }

            function init_form_fields()
            {
                $this->form_fields = array(
                    'APIKey' => array(
                        'title' => __('APIKey', 'voo'),
                        'type' => 'text',
                    ),
                );
            }
        }
    }
}

add_action('woocommerce_shipping_init', 'init_voo_shipping_class');
function add_voo_shipping_method($methods)
{
    $methods[] = 'voo_Shipping_Method';
    return $methods;
}

add_filter('woocommerce_shipping_methods', 'add_voo_shipping_method');

add_filter('woocommerce_states', 'voo_cities_and_zones');
function voo_cities_and_zones($states)
{
    $states['EG'] = [
        // Cairo Cities
        "5th Settlement" => "Cairo / 5th Settlement",
        "Abbaseya" => "Cairo / Abbaseya",
        "Downtown" => "Cairo / Downtown",
        "El Manyal" => "Cairo / El Manyal",
        "El Salam City" => "Cairo / El Salam City",
        "Heliopolis" => "Cairo / Heliopolis",
        "Maadi" => "Cairo / Maadi",
        "Madinaty" => "Cairo / Madinaty",
        "Mohandeseen" => "Cairo / Mohandeseen",
        "Mokatam" => "Cairo / Mokatam",
        "Nasr City" => "Cairo / Nasr City",
        "New Cairo" => "Cairo / New Cairo",
        "Rehab" => "Cairo / Rehab",
        "Shubra" => "Cairo / Shubra",
        "Shubra El Kheima" => "Cairo / Shubra El Kheima",
        "Zamalek" => "Cairo / Zamalek",
        "al badrashin" => "Cairo / al badrashin",
        "badr city" => "Cairo / badr city",
        "el obour city" => "Cairo / el obour city",
        "sherouk city" => "Cairo / sherouk city",

        // Helwan Cities
        'Helwan' => 'Helwan / Helwan',
        '15 of may city' => 'Helwan / 15 of may city',

        // Giza Cities
        'Giza' => "Giza / Giza",
        'Mohandeseen' => "Giza / Mohandeseen",
        'Haram' => "Giza / Haram",
        'Faisal' => "Giza / Faisal",
        'Imbaba' => "Giza / Imbaba",
        'Dokki' => "Giza / Dokki",
        'Elwahat' => "Giza / Elwahat",

        // 6 of october cities
        '6th of October City' => '6th Of October / 6th of October City',
        'Sheikh Zayed' => '6th Of October / Sheikh Zayed',

        // Alexanderia
        'Alexandria' => 'Alexandria / Alexandria',
        'North Coast' => 'Alexandria/ North Coast',

        // Gharbia Cities
        'Tanta' => 'Gharbia / Tanta',
        'Mahla' => 'Gharbia / Mahla',

        // Sharm El Shekih
        'Sharm el-sheikh' => 'Sharm el-sheikh',

        // Normal Cases
        "El Sharkia" => "El Sharkia",
        "Aswan" => "Aswan",
        "Asyut" => "Asyut",
        "Behira" => "Behira",
        "Benisuif" => "Benisuif",
        "Mansoura" => "Mansoura",
        "Dommyat" => "Dommyat",
        "Fayoum" => "Fayoum",
        "Ismailya" => "Ismailya",
        "Kafr el Sheikh" => "Kafr el Sheikh",
        "Luxor" => "Luxor",
        "Marsa Matrouh" => "Marsa Matrouh",
        "Minya" => "Minya",
        "Monofia" => "Monofia",
        "elwadi elgedid" => "elwadi elgedid",
        "Port said" => "Port said",
        "Quliob" => "Quliob",
        "Quena" => "Quena",
        "el gouna" => "El gouna",
        "Souhag" => "Souhag",
        "suez" => "Suez",
        
    ];
    return $states;

}
